Class: DeepSecurity::HostGroup

Inherits:
TransportObject show all
Defined in:
lib/deepsecurity/transport_objects/host_group.rb

Overview

Represents a computer group folder that computers can be assigned to for organizational purposes.

Constant Summary

Constants inherited from SavonHelper::MappingObject

SavonHelper::MappingObject::BLACK_LIST

High-Level SOAP Wrapper collapse

Instance Attribute Summary collapse

Attributes inherited from SavonHelper::MappingObject

#interface

Attributes included from SavonHelper::DSL

#alias_accessor

Method Summary

Methods inherited from TransportObject

#manager

Methods inherited from SavonHelper::CachingObject

all_cache_aspects, #cachable?, #cache, cache_aspects, cache_by_aspect, cache_key, #cache_key, from_savon, #store_in_cache

Methods inherited from SavonHelper::MappingObject

all_type_mappings, defined_attributes, from_savon, has_attribute_chain, #initialize, #to_json, #to_s, #to_savon, type_mappings

Methods included from SavonHelper::DSL

#array_boolean_accessor, #array_datetime_accessor, #array_double_accessor, #array_enum_accessor, #array_float__accessor, #array_integer_accessor, #array_ip_address_accessor, #array_object_accessor, #array_string_accessor, #attr_boolean_accessor, #attr_datetime_accessor, #attr_double_accessor, #attr_enum_accessor, #attr_float_accessor, #attr_integer_accessor, #attr_ip_address_accessor, #attr_object_accessor, #attr_string_accessor, #hint_object_accessor

Constructor Details

This class inherits a constructor from SavonHelper::MappingObject

Instance Attribute Details

#descriptionString

Description

Returns:



10
11
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 10

attr_string_accessor :description,
"Description"

#externalBoolean

Administrative external boolean for integration purposes

Returns:

  • (Boolean)


12
13
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 12

attr_boolean_accessor :external,
"Administrative external boolean for integration purposes"

#external_idString

Administrative external ID for integration purposes

Returns:



14
15
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 14

attr_string_accessor :external_id,
"Administrative external ID for integration purposes"

#idint

ID

Returns:

  • (int)


6
7
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 6

attr_integer_accessor :id,
"ID"

#nameString

Name

Returns:



8
9
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 8

attr_string_accessor :name,
"Name"

#parent_groupObject



27
28
29
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 27

hint_object_accessor :parent_group,
HostGroup,
'The paren group if existent'

#parent_group_idint

If the group belongs to a parent group, then this ID will be set and used to retrieve the parent group

Returns:

  • (int)


16
17
# File 'lib/deepsecurity/transport_objects/host_group.rb', line 16

attr_integer_accessor :parent_group_id,
"If the group belongs to a parent group, then this ID will be set and used to retrieve the parent group"